==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/AzureSqlProtectedItemExtendedInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.AzureSqlProtectedItemExtendedInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Additional information on Azure Sql specific protected item.
 * @property oldestRecoveryPoint The oldest backup copy available for this item in the service.
 * @property policyState State of the backup policy associated with this backup item.
 * @property recoveryPointCount Number of available backup copies associated with this backup item.
 */
public data class AzureSqlProtectedItemExtendedInfoArgs(
    public val oldestRecoveryPoint: Output<String>? = null,
    public val policyState: Output<String>? = null,
    public val recoveryPointCount: Output<Int>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.AzureSqlProtectedItemExtendedInfoArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.AzureSqlProtectedItemExtendedInfoArgs =
        com.pulumi.azurenative.recoveryservices.inputs.AzureSqlProtectedItemExtendedInfoArgs.builder()
            .oldestRecoveryPoint(oldestRecoveryPoint?.applyValue({ args0 -> args0 }))
            .policyState(policyState?.applyValue({ args0 -> args0 }))
            .recoveryPointCount(recoveryPointCount?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureSqlProtectedItemExtendedInfoArgs].
 */
@PulumiTagMarker
public class AzureSqlProtectedItemExtendedInfoArgsBuilder internal constructor() {
    private var oldestRecoveryPoint: Output<String>? = null

    private var policyState: Output<String>? = null

    private var recoveryPointCount: Output<Int>? = null

    /**
     * @param value The oldest backup copy available for this item in the service.
     */
    @JvmName("upwnkhustlvstlnq")
    public suspend fun oldestRecoveryPoint(`value`: Output<String>) {
        this.oldestRecoveryPoint = value
    }

    /**
     * @param value State of the backup policy associated with this backup item.
     */
    @JvmName("wlckpiahxovrrloj")
    public suspend fun policyState(`value`: Output<String>) {
        this.policyState = value
    }

    /**
     * @param value Number of available backup copies associated with this backup item.
     */
    @JvmName("ykvcjpincletqqed")
    public suspend fun recoveryPointCount(`value`: Output<Int>) {
        this.recoveryPointCount = value
    }

    /**
     * @param value The oldest backup copy available for this item in the service.
     */
    @JvmName("iwhwewnexrheauer")
    public suspend fun oldestRecoveryPoint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.oldestRecoveryPoint = mapped
    }

    /**
     * @param value State of the backup policy associated with this backup item.
     */
    @JvmName("waxlptyimprksyan")
    public suspend fun policyState(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.policyState = mapped
    }

    /**
     * @param value Number of available backup copies associated with this backup item.
     */
    @JvmName("dinrlvugfimipfgv")
    public suspend fun recoveryPointCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.recoveryPointCount = mapped
    }

    internal fun build(): AzureSqlProtectedItemExtendedInfoArgs =
        AzureSqlProtectedItemExtendedInfoArgs(
            oldestRecoveryPoint = oldestRecoveryPoint,
            policyState = policyState,
            recoveryPointCount = recoveryPointCount,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/AzureSqlProtectedItemExtendedInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.AzureSqlProtectedItemExtendedInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Additional information on Azure Sql specific protected item.
 * @property oldestRecoveryPoint The oldest backup copy available for this item in the service.
 * @property policyState State of the backup policy associated with this backup item.
 * @property recoveryPointCount Number of available backup copies associated with this backup item.
 */
public data class AzureSqlProtectedItemExtendedInfoArgs(
    public val oldestRecoveryPoint: Output<String>? = null,
    public val policyState: Output<String>? = null,
    public val recoveryPointCount: Output<Int>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.AzureSqlProtectedItemExtendedInfoArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.AzureSqlProtectedItemExtendedInfoArgs =
        com.pulumi.azurenative.recoveryservices.inputs.AzureSqlProtectedItemExtendedInfoArgs.builder()
            .oldestRecoveryPoint(oldestRecoveryPoint?.applyValue({ args0 -> args0 }))
            .policyState(policyState?.applyValue({ args0 -> args0 }))
            .recoveryPointCount(recoveryPointCount?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureSqlProtectedItemExtendedInfoArgs].
 */
@PulumiTagMarker
public class AzureSqlProtectedItemExtendedInfoArgsBuilder internal constructor() {
    private var oldestRecoveryPoint: Output<String>? = null

    private var policyState: Output<String>? = null

    private var recoveryPointCount: Output<Int>? = null

    /**
     * @param value The oldest backup copy available for this item in the service.
     */
    @JvmName("oswjjcsijrgpsyqh")
    public suspend fun oldestRecoveryPoint(`value`: Output<String>) {
        this.oldestRecoveryPoint = value
    }

    /**
     * @param value State of the backup policy associated with this backup item.
     */
    @JvmName("iaokqvmwfiwsekuo")
    public suspend fun policyState(`value`: Output<String>) {
        this.policyState = value
    }

    /**
     * @param value Number of available backup copies associated with this backup item.
     */
    @JvmName("rhyhftqinabqbwcq")
    public suspend fun recoveryPointCount(`value`: Output<Int>) {
        this.recoveryPointCount = value
    }

    /**
     * @param value The oldest backup copy available for this item in the service.
     */
    @JvmName("kdcdqwmnyaqasrww")
    public suspend fun oldestRecoveryPoint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.oldestRecoveryPoint = mapped
    }

    /**
     * @param value State of the backup policy associated with this backup item.
     */
    @JvmName("etclsdexqybvblnn")
    public suspend fun policyState(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.policyState = mapped
    }

    /**
     * @param value Number of available backup copies associated with this backup item.
     */
    @JvmName("kixqmijgpdaxhunq")
    public suspend fun recoveryPointCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.recoveryPointCount = mapped
    }

    internal fun build(): AzureSqlProtectedItemExtendedInfoArgs =
        AzureSqlProtectedItemExtendedInfoArgs(
            oldestRecoveryPoint = oldestRecoveryPoint,
            policyState = policyState,
            recoveryPointCount = recoveryPointCount,
        )
}
